extends Area2D
class_name LetterTile

@export_category("Background Textures")
@export var _empty_texture: AtlasTexture
@export var _hover_texture: AtlasTexture
@export var _invalid_texture: AtlasTexture
@export var _selected_texture: AtlasTexture
@export var _regular_texture: AtlasTexture

@export_category("Letter Tileset")
@export var _letter_tileset: CompressedTexture2D

var _selected: bool = false

@export var letter: String:
	set(value): 
		letter = value

var has_letter: bool:
	get:
		return !letter.is_empty()

var _normal_texture: AtlasTexture:
	get:
		return _regular_texture if has_letter else _empty_texture
		
func _ready():
	$Tile.texture = _normal_texture
	$Letter.texture = _letter_tileset
	$Letter.region_rect = RegionHelper.get_region(letter)
	
	add_to_group("letter_tiles", true)
	
func _on_mouse_entered():
	if not _selected:
		$Tile.texture = _hover_texture

func _on_mouse_exited():
	if not _selected:
		$Tile.texture = _normal_texture

func _on_input_event(_viewport, event, _shape_idx):	
	if event.is_action_pressed("select_tile"):
		_selected = not _selected
		print("pressed...")

func _notify_group_to_unselect():
	get_tree().call_group("letter_tiles", "unselect")
	
func unselect():
	_selected = false
	$Tile.texture = _normal_texture
	
func _on_letter_changed(new_letter):
	$Letter.region_rect = RegionHelper.get_region(new_letter)
	$Tile.texture = _normal_texture
